@@ -1,3 +1,4 @@
+import asyncio
 from selve.device import Device
 
 from selve.protocol import CommandTypeIveo, CommunicationType, DeviceClass, MethodCall, RepeaterState
@@ -104,105 +105,103 @@ class IveoCommandGetIds(Command):
 
 class IveoDevice(Device):
 
-    def __init__(self, gateway, iveoID, discover = False):
-        super().__init__(gateway, iveoID, discover)
+    def __init__(self, gateway, iveoID):
+        super().__init__(gateway, iveoID)
         self.communicationType = CommunicationType.IVEO
         self.deviceClass = DeviceClass.IVEO
-        if discover:
-            self.discover_properties()
     
-    def executeCommand(self, commandType, automatic = False):
+    async def executeCommand(self, commandType, automatic = False):
         if automatic:
             command = IveoCommandAutomatic(self.mask, commandType)
         else:
             command = IveoCommandManual(self.mask, commandType)
-        command.execute(self.gateway)
+        await command.execute(self.gateway)
         return command
 
-    def discover_properties(self):
+    async def discover_properties(self):
         try:
             command = IveoCommandGetConfig(self.ID)
-            command.execute(self.gateway)
+            await command.execute(self.gateway)
             self.device_type = command.deviceType
             self.name = command.name
             self.activity = command.activity
         except Exception as e1:
             _LOGGER.exception ("not : " + str(e1))
 
-    def setRepeaterState(self, state):
+    async def setRepeaterState(self, state):
         command = IveoCommandSetRepeater(state)
-        command.execute(self.gateway)
+        await command.execute(self.gateway)
 
-    def getRepeaterState(self):
+    async def getRepeaterState(self):
         command = IveoCommandGetRepeater()
-        command.execute(self.gateway)
+        await command.execute(self.gateway)
         return command
 
-    def setIveoLabel(self):
+    async def setIveoLabel(self):
         command = IveoCommandSetLabel(self.ID, self.name)
-        command.execute(self.gateway)
+        await command.execute(self.gateway)
 
-    def setIveoConfig(self):
+    async def setIveoConfig(self):
         command = IveoCommandSetConfig(self.ID, self.activity, self.device_type)
-        command.execute(self.gateway)
+        await command.execute(self.gateway)
 
-    def getIveoConfig(self):
+    async def getIveoConfig(self):
         command = IveoCommandGetConfig(self.ID)
-        command.execute(self.gateway)
+        await command.execute(self.gateway)
         self.device_type = command.deviceType
         self.name = command.name
         self.activity = command.activity
 
-    def resetIveoChannel(self):
+    async def resetIveoChannel(self):
         command = IveoCommandFactory(self.ID)
-        command.execute(self.gateway)
+        await command.execute(self.gateway)
         self.gateway.deleteDevice(self.ID)
 
-    def learnIveoChannel(self):
+    async def learnIveoChannel(self):
         command = IveoCommandLearn(self.ID)
-        command.execute(self.gateway)
+        await command.execute(self.gateway)
 
-    def setToLearnMode(self):
+    async def setToLearnMode(self):
         self.learnIveoChannel()        
 
-    def teachIveoChannel(self, channel):
+    async def teachIveoChannel(self, channel):
         command = IveoCommandTeach(channel)
         _LOGGER.info("Trying to teach channel " + str(channel))
-        command.execute(self.gateway)
+        await command.execute(self.gateway)
         if command.hasError:
             _LOGGER.info("Teaching failed for channel " + str(channel))
             return
-        if command.executed:
+        if await command.executed:
             _LOGGER.info("Channel " + str(channel) + "successfully taught" )
 
-    def manualIveoCommand(self, command):
+    async def manualIveoCommand(self, command):
         command = IveoCommandManual(self.mask, command)
-        command.execute(self.gateway)
+        await command.execute(self.gateway)
         return command
 
-    def automaticIveoCommand(self, command):
+    async def automaticIveoCommand(self, command):
         command = IveoCommandAutomatic(self.mask, command)
-        command.execute(self.gateway)
+        await command.execute(self.gateway)
         return command
 
 
-    def stop(self):
-        self.automaticIveoCommand(CommandTypeIveo.STOP)
+    async def stop(self):
+        await self.automaticIveoCommand(CommandTypeIveo.STOP)
 
-    def moveDown(self):
-        self.automaticIveoCommand(CommandTypeIveo.DRIVEDOWN)
+    async def moveDown(self):
+        await self.automaticIveoCommand(CommandTypeIveo.DRIVEDOWN)
     
-    def moveUp(self):
-        self.automaticIveoCommand(CommandTypeIveo.DRIVEUP)
+    async def moveUp(self):
+        await self.automaticIveoCommand(CommandTypeIveo.DRIVEUP)
     
-    def moveIntermediatePosition1(self):
-        self.manualIveoCommand(CommandTypeIveo.POSITION_1)
+    async def moveIntermediatePosition1(self):
+        await self.manualIveoCommand(CommandTypeIveo.POSITION_1)
 
-    def moveIntermediatePosition2(self):
-        self.manualIveoCommand(CommandTypeIveo.POSITION_2)
+    async def moveIntermediatePosition2(self):
+        await self.manualIveoCommand(CommandTypeIveo.POSITION_2)
     
-    def deleteDevice(self):
-        self.resetIveoChannel()
+    async def deleteDevice(self):
+        await self.resetIveoChannel()
 
-    def saveDevice(self):
-        self.teachIveoChannel(self.ID)
\ No newline at end of file
+    async def saveDevice(self):
+        await self.teachIveoChannel(self.ID)
\ No newline at end of file
