@@ -107,12 +107,10 @@ class CommeoSenSimGetTest(CommandSingle):
         self.testMode = bool(methodResponse.parameters[1][1])
     
 class SenSimDevice(Device):
-    def __init__(self, gateway, id, discover = False):
-        super().__init__(gateway, id, discover)
+    def __init__(self, gateway, id):
+        super().__init__(gateway, id)
         self.communicationType = CommunicationType.COMMEO
         self.deviceClass = DeviceClass.SENSIM
-        if discover:
-            self.discover_properties()
 
     def discover_properties(self):
         try:
